declare class ResolverBase {
    constructor();
    /**
     * Returns all variants of a resolver
     *
     * Example:
     *  Passing in "app.{lang=en}.hello.{ok=p1}.blog" will return
     *    [
     *      "app.{lang=en}.hello.{ok=p1}.blog",
     *      "app.{lang}.hello.{ok=p1}.blog",
     *      "app.{lang=en}.hello.{ok}.blog",
     *      "app.{lang}.hello.{ok}.blog",
     *    ]
     */
    readonly variants: (resolver: string) => Set<string>;
    /**
     * Given a partial resolver like:
     *    "stringifyr.{locale=it}.blog.{post}"
     *
     * Return a map of all the variables and their maybe existing values.
     *    {
     *      locale: 'it',
     *      post: undefined,
     *    }
     */
    readonly variables: (resolver: string) => Record<string, string>;
}
export declare const Resolver: ResolverBase;
export {};
